/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtPurchasing.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPurchasing.h"

#line 26 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/sip/QtPurchasing/qinappstore.sip"
#include <qinappstore.h>
#line 29 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/sip/QtPurchasing/qinapptransaction.sip"
#include <qinapptransaction.h>
#line 36 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/sip/QtPurchasing/qinappproduct.sip"
#include <qinappproduct.h>
#line 39 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 77 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 83 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 86 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/python-pyqt5-purchasing/src/PyQtPurchasing-5.15.6/build/QtPurchasing/sipQtPurchasingQInAppStore.cpp"


class sipQInAppStore : public ::QInAppStore
{
public:
    sipQInAppStore(::QObject*);
    virtual ~sipQInAppStore();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQInAppStore(const sipQInAppStore &);
    sipQInAppStore &operator = (const sipQInAppStore &);

    char sipPyMethods[7];
};

sipQInAppStore::sipQInAppStore(::QObject*a0): ::QInAppStore(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQInAppStore::~sipQInAppStore()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQInAppStore::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPurchasing_qt_metaobject(sipPySelf, sipType_QInAppStore);

    return ::QInAppStore::metaObject();
}

int sipQInAppStore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QInAppStore::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPurchasing_qt_metacall(sipPySelf, sipType_QInAppStore, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQInAppStore::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPurchasing_qt_metacast(sipPySelf, sipType_QInAppStore, _clname, &sipCpp) ? sipCpp : ::QInAppStore::qt_metacast(_clname));
}

bool sipQInAppStore::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QInAppStore::event(a0);

    extern bool sipVH_QtPurchasing_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPurchasing_5(sipGILState, sipImportedVirtErrorHandlers_QtPurchasing_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQInAppStore::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QInAppStore::eventFilter(a0, a1);

    extern bool sipVH_QtPurchasing_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPurchasing_4(sipGILState, sipImportedVirtErrorHandlers_QtPurchasing_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQInAppStore::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QInAppStore::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPurchasing_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPurchasing_3(sipGILState, sipImportedVirtErrorHandlers_QtPurchasing_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInAppStore::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QInAppStore::childEvent(a0);
        return;
    }

    extern void sipVH_QtPurchasing_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPurchasing_2(sipGILState, sipImportedVirtErrorHandlers_QtPurchasing_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInAppStore::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QInAppStore::customEvent(a0);
        return;
    }

    extern void sipVH_QtPurchasing_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPurchasing_1(sipGILState, sipImportedVirtErrorHandlers_QtPurchasing_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInAppStore::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QInAppStore::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPurchasing_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPurchasing_0(sipGILState, sipImportedVirtErrorHandlers_QtPurchasing_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInAppStore::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QInAppStore::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPurchasing_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPurchasing_0(sipGILState, sipImportedVirtErrorHandlers_QtPurchasing_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QInAppStore_restorePurchases, "restorePurchases(self)");

extern "C" {static PyObject *meth_QInAppStore_restorePurchases(PyObject *, PyObject *);}
static PyObject *meth_QInAppStore_restorePurchases(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QInAppStore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInAppStore, &sipCpp))
        {
            sipCpp->restorePurchases();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInAppStore, sipName_restorePurchases, doc_QInAppStore_restorePurchases);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInAppStore_registerProduct, "registerProduct(self, productType: QInAppProduct.ProductType, identifier: str|None)");

extern "C" {static PyObject *meth_QInAppStore_registerProduct(PyObject *, PyObject *);}
static PyObject *meth_QInAppStore_registerProduct(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QInAppProduct::ProductType a0;
        const ::QString* a1;
        int a1State = 0;
        ::QInAppStore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QInAppStore, &sipCpp, sipType_QInAppProduct_ProductType, &a0, sipType_QString, &a1, &a1State))
        {
            sipCpp->registerProduct(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInAppStore, sipName_registerProduct, doc_QInAppStore_registerProduct);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInAppStore_registeredProduct, "registeredProduct(self, identifier: str|None) -> QInAppProduct|None");

extern "C" {static PyObject *meth_QInAppStore_registeredProduct(PyObject *, PyObject *);}
static PyObject *meth_QInAppStore_registeredProduct(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QInAppStore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QInAppStore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QInAppProduct*sipRes;

            sipRes = sipCpp->registeredProduct(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QInAppProduct, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInAppStore, sipName_registeredProduct, doc_QInAppStore_registeredProduct);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInAppStore_setPlatformProperty, "setPlatformProperty(self, propertyName: str|None, value: str|None)");

extern "C" {static PyObject *meth_QInAppStore_setPlatformProperty(PyObject *, PyObject *);}
static PyObject *meth_QInAppStore_setPlatformProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QInAppStore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QInAppStore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp->setPlatformProperty(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInAppStore, sipName_setPlatformProperty, doc_QInAppStore_setPlatformProperty);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QInAppStore(void *, const sipTypeDef *);}
static void *cast_QInAppStore(void *sipCppV, const sipTypeDef *targetType)
{
    ::QInAppStore *sipCpp = reinterpret_cast< ::QInAppStore *>(sipCppV);

    if (targetType == sipType_QInAppStore)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QInAppStore(void *, int);}
static void release_QInAppStore(void *sipCppV, int)
{
    ::QInAppStore *sipCpp = reinterpret_cast< ::QInAppStore *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QInAppStore(Py_ssize_t);}
static void *array_QInAppStore(Py_ssize_t sipNrElem)
{
    return new ::QInAppStore[sipNrElem];
}


extern "C" {static void array_delete_QInAppStore(void *);}
static void array_delete_QInAppStore(void *sipCpp)
{
    delete[] reinterpret_cast< ::QInAppStore *>(sipCpp);
}


extern "C" {static void dealloc_QInAppStore(sipSimpleWrapper *);}
static void dealloc_QInAppStore(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQInAppStore *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QInAppStore(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QInAppStore(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QInAppStore(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQInAppStore *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQInAppStore(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QInAppStore[] = {{4, 0, 1}};


static PyMethodDef methods_QInAppStore[] = {
    {sipName_registerProduct, meth_QInAppStore_registerProduct, METH_VARARGS, doc_QInAppStore_registerProduct},
    {sipName_registeredProduct, meth_QInAppStore_registeredProduct, METH_VARARGS, doc_QInAppStore_registeredProduct},
    {sipName_restorePurchases, meth_QInAppStore_restorePurchases, METH_VARARGS, doc_QInAppStore_restorePurchases},
    {sipName_setPlatformProperty, meth_QInAppStore_setPlatformProperty, METH_VARARGS, doc_QInAppStore_setPlatformProperty}
};

PyDoc_STRVAR(doc_QInAppStore, "\1QInAppStore(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QInAppStore[] = {
    {"transactionReady(QInAppTransaction*)", "\1transactionReady(self, transaction: QInAppTransaction|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"productUnknown(QInAppProduct::ProductType,QString)", "\1productUnknown(self, productType: QInAppProduct.ProductType, identifier: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"productRegistered(QInAppProduct*)", "\1productRegistered(self, product: QInAppProduct|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QInAppStore = {
    &::QInAppStore::staticMetaObject,
    0,
    signals_QInAppStore,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPurchasing_QInAppStore = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QInAppStore,
        SIP_NULLPTR,
        &plugin_QInAppStore,
    },
    {
        sipNameNr_QInAppStore,
        {0, 0, 1},
        4, methods_QInAppStore,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QInAppStore,
    -1,
    -1,
    supers_QInAppStore,
    SIP_NULLPTR,
    init_type_QInAppStore,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QInAppStore,
    SIP_NULLPTR,
    array_QInAppStore,
    SIP_NULLPTR,
    release_QInAppStore,
    cast_QInAppStore,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QInAppStore,
    sizeof (::QInAppStore),
};
